import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:rflutter_alert/rflutter_alert.dart';
import 'package:url_launcher/url_launcher.dart';

class FunctionHelper {
  Size _screenSize(BuildContext context) {
    return MediaQuery.of(context).size;
  }

  /// Get percent base on screen height device
  double screenHeight(BuildContext context, double percent) {
    return (_screenSize(context).height * percent) / 100;
  }

  /// Get percent base on screen width device
  double screenWidth(BuildContext context, double percent) {
    return (_screenSize(context).width * percent) / 100;
  }

  void callTo({String phoneNumber}) {
    launch("tel:$phoneNumber");
  }

  void mailTo({String email}) {
    launch("mailto:$email");
  }

  void clipBoard({String content}) {
    Clipboard.setData(ClipboardData(text: content));
  }

  Future<void> showContentAlert(
      {BuildContext context,
      String title,
      Widget content,
      List<DialogButton> buttons}) async {
    await Alert(
            context: context, title: title, content: content, buttons: buttons)
        .show();
  }

  Future<void> showErrorButtonAlert(
      {BuildContext context,
      String title,
      String description,
      List<DialogButton> buttons}) async {
    await Alert(
            context: context,
            type: AlertType.error,
            title: title,
            desc: description,
            buttons: buttons)
        .show();
  }

  Future<void> showWarningButtonAlert(
      {BuildContext context,
        String title,
        String description,
        List<DialogButton> buttons}) async {
    await Alert(
        context: context,
        type: AlertType.warning,
        title: title,
        desc: description,
        buttons: buttons)
        .show();
  }

  Future<void> showSuccessButtonAlert(
      {BuildContext context,
        String title,
        String description,
        List<DialogButton> buttons}) async {
    await Alert(
        context: context,
        type: AlertType.success,
        title: title,
        desc: description,
        buttons: buttons)
        .show();
  }
}
