import 'package:bottom_navy_bar/bottom_navy_bar.dart';
import 'package:bubble_bottom_bar/bubble_bottom_bar.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter_kz_library/flutter_kz_library.dart';
import 'package:flutter_speed_dial/flutter_speed_dial.dart';
import 'package:progress_dialog/progress_dialog.dart';
import 'package:rflutter_alert/rflutter_alert.dart';
import 'package:toast/toast.dart';
import 'package:intl/intl.dart';

class Statics {

  static String contentType({ContentType type}) {
    switch (type) {
      case ContentType.json:
        return 'application/json';

      case ContentType.formData:
        return 'multipart/form-data';

      default:
        return 'application/json';
    }
  }

  static String authType({AuthType type, String token}) {
    switch (type) {
      case AuthType.basic:
        return 'Basic ' + token;

      case AuthType.bearer:
        return 'Bearer ' + token;

      default:
        return 'Bearer ' + token;
    }
  }

  static int toastPosition({toastGravity type}) {
    switch (type) {
      case toastGravity.top:
        return Toast.TOP;

      case toastGravity.center:
        return Toast.CENTER;

      case toastGravity.bottom:
        return Toast.BOTTOM;

      default:
        return Toast.CENTER;
    }
  }

  static BubbleBottomBarItem bubbleBottomBarItem(
      {Widget icon, Widget activeIcon, Color backgroundColor, Widget title}) {
    return BubbleBottomBarItem(
        icon: icon,
        activeIcon: activeIcon,
        backgroundColor: backgroundColor,
        title: title);
  }

  static BottomNavyBarItem bottomNavyBarItem(
      {Widget icon, Widget title, Color activeColor, Color inactiveColor}) {
    return BottomNavyBarItem(
      icon: icon,
      title: title,
      activeColor: activeColor,
      inactiveColor: inactiveColor,
    );
  }

  static SpeedDialChild speedDialChild(
      {Widget child,
      Color backgroundColor,
      String label,
      TextStyle labelStyle,
      VoidCallback onTap}) {
    return SpeedDialChild(
        child: child,
        backgroundColor: backgroundColor,
        label: label,
        labelStyle: labelStyle,
        onTap: onTap);
  }

  static DateFormat dateFormat({ DateFormatType format }) {
    switch (format) {
      case DateFormatType.dMY:
        return DateFormat("dd/MM/yyyy");

      case DateFormatType.yMd:
        return DateFormat("yyyy/MM/dd");

      case DateFormatType.dMYHms:
        return DateFormat("dd/MM/yyyy HH:mm");

      case DateFormatType.yMdHms:
        return DateFormat("yyyy/MM/dd HH:mm");

      default:
        return DateFormat("dd/MM/yyyy");
    }
  }

  static DialogButton dialogButton({Widget child, VoidCallback onPressed}) {
    return DialogButton(
      onPressed: onPressed,
      child: child,
    );
  }

  static ProgressDialogType progressDialogType({progressDialog type}) {
    switch (type) {
      case progressDialog.download:
        return ProgressDialogType.Download;
      case progressDialog.progress:
        return ProgressDialogType.Normal;
      default:
        return ProgressDialogType.Normal;
    }

  }
}

class SelectListModel {
  String itemValue;
  String itemText;

  SelectListModel({this.itemValue, this.itemText});
}

enum ContentType { json, formData }

enum AuthType { basic, bearer }

enum toastGravity { top, center, bottom }

enum DateFormatType { yMd, dMY, yMdHms, dMYHms }

enum progressDialog { download, progress }
